function Y = ar_gen_v2(a, e)
% PURPOSE: Generate AR(p) with parameter a and errors e.
%--------------------------------------------------------------------------
% USAGE: Y = ar_gen_v2(a, e)
% where: a = coefficients (1xp or px1)
%             a(j) = AR(j) coefficient for j = 1, ..., p
%        e = error term (T x 1)
%--------------------------------------------------------------------------
% RETURNS: Y = AR(p) process (T x 1)
%--------------------------------------------------------------------------
% References: 
%   Jonathan B. Hill & Kaiji Motegi (2018). A Max-Correlation White Noise 
%       Test for Weakly Dependent Time Series. Working Paper at UNC
%       Chapel Hill and Kobe University. 
% -------------------------------------------------------------------------
% Written by:
%    Kaiji Motegi
%    Associate professor
%    Graduate School of Economics, Kobe University
%--------------------------------------------------------------------------
% Last updated:
%    September 24, 2018.
% -------------------------------------------------------------------------

T = length(e);
p = length(a);
Y = e;

for t = 2:T
     if t <= p
         for j = 1:(t-1)
              Y(t) = Y(t) + Y(t-j) * a(j);
         end
     elseif t > p
         for j = 1:p
              Y(t) = Y(t) + Y(t-j) * a(j);
         end     
     end
end


end

