function y = bilinear_gen_v1(a, e)
% PURPOSE: Generate a simple bilinear process with parameter a and errors e.
%--------------------------------------------------------------------------
% USAGE: y = bilinear_gen_v1(a, e)
% where: a = coefficient (scalar)
%        e = error term (T x 1)
%--------------------------------------------------------------------------
% RETURNS: y = bilinear process (T x 1)
%--------------------------------------------------------------------------
% References: 
%   Jonathan B. Hill & Kaiji Motegi (2018). A Max-Correlation White Noise 
%       Test for Weakly Dependent Time Series. Working Paper at UNC
%       Chapel Hill and Kobe University. 
% -------------------------------------------------------------------------
% Written by:
%    Kaiji Motegi
%    Associate professor
%    Graduate School of Economics, Kobe University
%--------------------------------------------------------------------------
% Last updated:
%    September 24, 2018.
% -------------------------------------------------------------------------

T = length(e);
y = zeros(T,1);

for t = 3:T 
     y(t) = a * e(t-1) * y(t-2) + e(t);
end

end

