function y = garch11_gen_v2(param, e)
% PURPOSE: Generate GARCH(1,1) process.
%--------------------------------------------------------------------------
% USAGE: y = garch11_gen_v2(param, e)
% where: param = parameters (3x1 or 1x3)
%                  param(1) = w 
%                  param(2) = a
%                  param(3) = b 
%        e = error term (T x 1)
%--------------------------------------------------------------------------
% RETURNS: y = GARCH(1,1) process (T x 1)
% -------------------------------------------------------------------------
% Specification: y(t) = sqrt(sigsq(t)) * e(t)
%                sigsq(t) = w + a * y(t-1)^2 + b * sigsq(t-1)
%--------------------------------------------------------------------------
% References: 
%   Jonathan B. Hill & Kaiji Motegi (2018). A Max-Correlation White Noise 
%       Test for Weakly Dependent Time Series. Working Paper at UNC
%       Chapel Hill and Kobe University. 
% -------------------------------------------------------------------------
% Written by:
%    Kaiji Motegi
%    Associate professor
%    Graduate School of Economics, Kobe University
%--------------------------------------------------------------------------
% Last updated:
%    September 24, 2018.
% -------------------------------------------------------------------------

T = length(e);    % sample size
w = param(1);     % constant
a = param(2);     % ARCH parameter
b = param(3);     % GARCH parameter

y = zeros(T,1);
sigsq = w;        % save memory by not creating a vector for sigma^2

% Generate the series
y(1) = sqrt(sigsq) * e(1);
for i = 2:T
     sigsq = w + a * y(i-1)^2 + b * sigsq;   % update sigma^2
     y(i) = sqrt(sigsq) * e(i);
end

end

