function y = ma_gen_v2(a, e)
% PURPOSE: Generate MA(q) with parameter a and errors e.
%--------------------------------------------------------------------------
% USAGE: y = ma_gen_v2(a, e)
% where: a = coefficient (qx1  or 1xq)
%               a(j) = MA(j) coefficient, j = 1, 2, ..., q.
%        e = error term (T x 1)
%--------------------------------------------------------------------------
% RETURNS: y = MA(q) process (T x 1)
%--------------------------------------------------------------------------
% References: 
%   Jonathan B. Hill & Kaiji Motegi (2018). A Max-Correlation White Noise 
%       Test for Weakly Dependent Time Series. Working Paper at UNC
%       Chapel Hill and Kobe University. 
% -------------------------------------------------------------------------
% Written by:
%    Kaiji Motegi
%    Associate professor
%    Graduate School of Economics, Kobe University
%--------------------------------------------------------------------------
% Last updated:
%    September 24, 2018.
% -------------------------------------------------------------------------

T = length(e);
q = length(a);
y = e;

for t = (q+1):T 
     for j = 1:q
          y(t) = y(t) + a(j) * e(t-j);
     end
end

end

